You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by tn...@apache.org on 2013/04/17 19:38:18 UTC

svn commit: r1469004 [4/11] - in /commons/proper/collections/trunk: ./ src/main/java/org/apache/commons/collections/ src/main/java/org/apache/commons/collections/bag/ src/main/java/org/apache/commons/collections/bidimap/ src/main/java/org/apache/common...

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/SequencesComparator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/SequencesComparator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/SequencesComparator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/SequencesComparator.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.comparators.sequence;
+package org.apache.commons.collections4.comparators.sequence;
 
 import java.util.List;
 

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/Snake.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/Snake.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/Snake.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/Snake.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.comparators.sequence;
+package org.apache.commons.collections4.comparators.sequence;
 
 /**
  * This class is a simple placeholder to hold the end part of a path

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/package-info.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/package-info.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/comparators/sequence/package-info.java Wed Apr 17 17:37:03 2013
@@ -78,4 +78,4 @@
  *
  * @version $Id$
  */
-package org.apache.commons.collections.comparators.sequence;
+package org.apache.commons.collections4.comparators.sequence;

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/AbstractQuantifierPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/AbstractQuantifierPredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/AbstractQuantifierPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/AbstractQuantifierPredicate.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Abstract base class for quantification predicates, e.g. All, Any, None.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/AllPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/AllPredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/AllPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/AllPredicate.java Wed Apr 17 17:37:03 2013
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
-import static org.apache.commons.collections.functors.FunctorUtils.coerce;
-import static org.apache.commons.collections.functors.FunctorUtils.validate;
-import static org.apache.commons.collections.functors.TruePredicate.truePredicate;
+import static org.apache.commons.collections4.functors.FunctorUtils.coerce;
+import static org.apache.commons.collections4.functors.FunctorUtils.validate;
+import static org.apache.commons.collections4.functors.TruePredicate.truePredicate;
 
 import java.io.Serializable;
 import java.util.Collection;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that returns true if all the

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/AndPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/AndPredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/AndPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/AndPredicate.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that returns true if both the predicates return true.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/AnyPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/AnyPredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/AnyPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/AnyPredicate.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 import java.util.Collection;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that returns true if any of the

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/CatchAndRethrowClosure.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/CatchAndRethrowClosure.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/CatchAndRethrowClosure.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/CatchAndRethrowClosure.java Wed Apr 17 17:37:03 2013
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
-import org.apache.commons.collections.Closure;
-import org.apache.commons.collections.FunctorException;
+import org.apache.commons.collections4.Closure;
+import org.apache.commons.collections4.FunctorException;
 
 /**
  * {@link Closure} that catches any checked exception and re-throws it as a

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ChainedClosure.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ChainedClosure.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ChainedClosure.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ChainedClosure.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 import java.util.Collection;
 
-import org.apache.commons.collections.Closure;
+import org.apache.commons.collections4.Closure;
 
 /**
  * Closure implementation that chains the specified closures together.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ChainedTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ChainedTransformer.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ChainedTransformer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ChainedTransformer.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 import java.util.Collection;
 
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Transformer implementation that chains the specified transformers together.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/CloneTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/CloneTransformer.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/CloneTransformer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/CloneTransformer.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Transformer implementation that returns a clone of the input object.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ClosureTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ClosureTransformer.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ClosureTransformer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ClosureTransformer.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Closure;
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.Closure;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Transformer implementation that calls a Closure using the input object

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ComparatorPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ComparatorPredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ComparatorPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ComparatorPredicate.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 import java.util.Comparator;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate that compares the input object with the one stored in the predicate using a comparator.
@@ -155,7 +155,7 @@ public class ComparatorPredicate<T> impl
      *     <li><code>comparator.compare(object, input) <= 0 && criterion == LESS_OR_EQUAL</code></li>
      * </ul>
      *
-     * @see org.apache.commons.collections.Predicate#evaluate(java.lang.Object)
+     * @see org.apache.commons.collections4.Predicate#evaluate(java.lang.Object)
      * @see java.util.Comparator#compare(java.lang.Object first, java.lang.Object second)
      * 
      * @param target  the target object to compare to

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ConstantFactory.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ConstantFactory.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ConstantFactory.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ConstantFactory.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Factory;
+import org.apache.commons.collections4.Factory;
 
 /**
  * Factory implementation that returns the same constant each time.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ConstantTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ConstantTransformer.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ConstantTransformer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ConstantTransformer.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Transformer implementation that returns the same constant each time.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/DefaultEquator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/DefaultEquator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/DefaultEquator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/DefaultEquator.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 /**
  * Default {@link Equator} implementation.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/EqualPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/EqualPredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/EqualPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/EqualPredicate.java Wed Apr 17 17:37:03 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
-import static org.apache.commons.collections.functors.NullPredicate.nullPredicate;
+import static org.apache.commons.collections4.functors.NullPredicate.nullPredicate;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that returns true if the input is the same object

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/Equator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/Equator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ExceptionClosure.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ExceptionClosure.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Closure;
-import org.apache.commons.collections.FunctorException;
+import org.apache.commons.collections4.Closure;
+import org.apache.commons.collections4.FunctorException;
 
 /**
  * Closure implementation that always throws an exception.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ExceptionFactory.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ExceptionFactory.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ExceptionFactory.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ExceptionFactory.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Factory;
-import org.apache.commons.collections.FunctorException;
+import org.apache.commons.collections4.Factory;
+import org.apache.commons.collections4.FunctorException;
 
 /**
  * Factory implementation that always throws an exception.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ExceptionPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ExceptionPredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ExceptionPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ExceptionPredicate.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.FunctorException;
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.FunctorException;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that always throws an exception.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ExceptionTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ExceptionTransformer.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ExceptionTransformer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ExceptionTransformer.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.FunctorException;
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.FunctorException;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Transformer implementation that always throws an exception.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/FactoryTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/FactoryTransformer.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/FactoryTransformer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/FactoryTransformer.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Factory;
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.Factory;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Transformer implementation that calls a Factory and returns the result.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/FalsePredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/FalsePredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/FalsePredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/FalsePredicate.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that always returns false.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ForClosure.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ForClosure.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ForClosure.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ForClosure.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Closure;
+import org.apache.commons.collections4.Closure;
 
 /**
  * Closure implementation that calls another closure n times, like a for loop.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/FunctorUtils.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/FunctorUtils.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/FunctorUtils.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/FunctorUtils.java Wed Apr 17 17:37:03 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.util.Collection;
 
-import org.apache.commons.collections.Closure;
-import org.apache.commons.collections.Predicate;
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.Closure;
+import org.apache.commons.collections4.Predicate;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Internal utilities for functors.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/IdentityPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/IdentityPredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/IdentityPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/IdentityPredicate.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that returns true if the input is the same object

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/IfClosure.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/IfClosure.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/IfClosure.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/IfClosure.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Closure;
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Closure;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Closure implementation acts as an if statement calling one or other closure

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InstanceofPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InstanceofPredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InstanceofPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InstanceofPredicate.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that returns true if the input is an instanceof

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InstantiateFactory.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InstantiateFactory.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InstantiateFactory.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InstantiateFactory.java Wed Apr 17 17:37:03 2013
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
 
-import org.apache.commons.collections.Factory;
-import org.apache.commons.collections.FunctorException;
+import org.apache.commons.collections4.Factory;
+import org.apache.commons.collections4.FunctorException;
 
 /**
  * Factory implementation that creates a new object instance by reflection.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InstantiateTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InstantiateTransformer.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InstantiateTransformer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InstantiateTransformer.java Wed Apr 17 17:37:03 2013
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
 
-import org.apache.commons.collections.FunctorException;
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.FunctorException;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Transformer implementation that creates a new object instance by reflection.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InvokerTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InvokerTransformer.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InvokerTransformer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InvokerTransformer.java Wed Apr 17 17:37:03 2013
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 
-import org.apache.commons.collections.FunctorException;
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.FunctorException;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Transformer implementation that creates a new object instance by reflection.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/MapTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/MapTransformer.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/MapTransformer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/MapTransformer.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 import java.util.Map;
 
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Transformer implementation that returns the value held in a specified map

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NOPClosure.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NOPClosure.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NOPClosure.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NOPClosure.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Closure;
+import org.apache.commons.collections4.Closure;
 
 /**
  * Closure implementation that does nothing.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NOPTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NOPTransformer.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NOPTransformer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NOPTransformer.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Transformer implementation that does nothing.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NonePredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NonePredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NonePredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NonePredicate.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 import java.util.Collection;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that returns true if none of the

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NotNullPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NotNullPredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NotNullPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NotNullPredicate.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that returns true if the input is not null.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NotPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NotPredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NotPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NotPredicate.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that returns the opposite of the decorated predicate.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsExceptionPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsExceptionPredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsExceptionPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsExceptionPredicate.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.FunctorException;
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.FunctorException;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that throws an exception if the input is null.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsFalsePredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsFalsePredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsFalsePredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsFalsePredicate.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that returns false if the input is null.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsTruePredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsTruePredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsTruePredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsTruePredicate.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that returns true if the input is null.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullPredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullPredicate.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that returns true if the input is null.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/OnePredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/OnePredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/OnePredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/OnePredicate.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 import java.util.Collection;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that returns true if only one of the

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/OrPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/OrPredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/OrPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/OrPredicate.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that returns true if either of the predicates return true.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/PredicateDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/PredicateDecorator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/PredicateDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/PredicateDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Defines a predicate that decorates one or more other predicates.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/PredicateTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/PredicateTransformer.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/PredicateTransformer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/PredicateTransformer.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Predicate;
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.Predicate;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Transformer implementation that calls a Predicate using the input object

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/PrototypeFactory.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/PrototypeFactory.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/PrototypeFactory.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/PrototypeFactory.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
@@ -25,8 +25,8 @@ import java.io.Serializable;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 
-import org.apache.commons.collections.Factory;
-import org.apache.commons.collections.FunctorException;
+import org.apache.commons.collections4.Factory;
+import org.apache.commons.collections4.FunctorException;
 
 /**
  * Factory implementation that creates a new instance each time based on a prototype.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/StringValueTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/StringValueTransformer.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/StringValueTransformer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/StringValueTransformer.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Transformer implementation that returns the result of calling

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/SwitchClosure.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/SwitchClosure.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/SwitchClosure.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/SwitchClosure.java Wed Apr 17 17:37:03 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 import java.util.Map;
 
-import org.apache.commons.collections.Closure;
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Closure;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Closure implementation calls the closure whose predicate returns true,

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/SwitchTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/SwitchTransformer.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/SwitchTransformer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/SwitchTransformer.java Wed Apr 17 17:37:03 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 import java.util.Map;
 
-import org.apache.commons.collections.Predicate;
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.Predicate;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Transformer implementation calls the transformer whose predicate returns true,

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformedPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformedPredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformedPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformedPredicate.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Predicate;
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.Predicate;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Predicate implementation that transforms the given object before invoking

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformerClosure.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformerClosure.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformerClosure.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformerClosure.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Closure;
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.Closure;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Closure implementation that calls a Transformer using the input object

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformerPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformerPredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformerPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformerPredicate.java Wed Apr 17 17:37:03 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.FunctorException;
-import org.apache.commons.collections.Predicate;
-import org.apache.commons.collections.Transformer;
+import org.apache.commons.collections4.FunctorException;
+import org.apache.commons.collections4.Predicate;
+import org.apache.commons.collections4.Transformer;
 
 /**
  * Predicate implementation that returns the result of a transformer.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TruePredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TruePredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TruePredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TruePredicate.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that always returns true.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/UniquePredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/UniquePredicate.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/UniquePredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/UniquePredicate.java Wed Apr 17 17:37:03 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 import java.util.HashSet;
 import java.util.Set;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Predicate implementation that returns true the first time an object is

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/WhileClosure.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/WhileClosure.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/WhileClosure.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/WhileClosure.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 import java.io.Serializable;
 
-import org.apache.commons.collections.Closure;
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Closure;
+import org.apache.commons.collections4.Predicate;
 
 /**
  * Closure implementation that executes a closure repeatedly until a condition is met,

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/package-info.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractEmptyIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractEmptyIterator.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
 import java.util.NoSuchElementException;
 

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractEmptyMapIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractEmptyMapIterator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractEmptyMapIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractEmptyMapIterator.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
 /** 
  * Provides an implementation of an empty map iterator.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractIteratorDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractIteratorDecorator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractIteratorDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractIteratorDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
 import java.util.Iterator;
 

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractListIteratorDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractListIteratorDecorator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractListIteratorDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractListIteratorDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
 import java.util.ListIterator;
 

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractMapIteratorDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractMapIteratorDecorator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractMapIteratorDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractMapIteratorDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
-import org.apache.commons.collections.MapIterator;
+import org.apache.commons.collections4.MapIterator;
 
 /**
  * Provides basic behaviour for decorating a map iterator with extra functionality.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractOrderedMapIteratorDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractOrderedMapIteratorDecorator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractOrderedMapIteratorDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractOrderedMapIteratorDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
-import org.apache.commons.collections.OrderedMapIterator;
+import org.apache.commons.collections4.OrderedMapIterator;
 
 /**
  * Provides basic behaviour for decorating an ordered map iterator with extra functionality.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractUntypedIteratorDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractUntypedIteratorDecorator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractUntypedIteratorDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractUntypedIteratorDecorator.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
 import java.util.Iterator;
 

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/ArrayIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/ArrayIterator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/ArrayIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/ArrayIterator.java Wed Apr 17 17:37:03 2013
@@ -14,19 +14,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
 import java.lang.reflect.Array;
 import java.util.NoSuchElementException;
 
-import org.apache.commons.collections.ResettableIterator;
+import org.apache.commons.collections4.ResettableIterator;
 
 /** 
  * Implements an {@link java.util.Iterator Iterator} over any array.
  * <p>
  * The array can be either an array of object or of primitives. If you know 
  * that you have an object array, the 
- * {@link org.apache.commons.collections.iterators.ObjectArrayIterator ObjectArrayIterator}
+ * {@link org.apache.commons.collections4.iterators.ObjectArrayIterator ObjectArrayIterator}
  * class is a better choice, as it will perform better.
  * <p>
  * The iterator implements a {@link #reset} method, allowing the reset of 

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/ArrayListIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/ArrayListIterator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/ArrayListIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/ArrayListIterator.java Wed Apr 17 17:37:03 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
 import java.lang.reflect.Array;
 import java.util.ListIterator;
 import java.util.NoSuchElementException;
 
-import org.apache.commons.collections.ResettableListIterator;
+import org.apache.commons.collections4.ResettableListIterator;
 
 /**
  * Implements a {@link ListIterator} over an array. 
@@ -33,7 +33,7 @@ import org.apache.commons.collections.Re
  * This iterator does not support {@link #add(Object)} or {@link #remove()}, as the array 
  * cannot be changed in size. The {@link #set(Object)} method is supported however.
  *
- * @see org.apache.commons.collections.iterators.ArrayIterator
+ * @see org.apache.commons.collections4.iterators.ArrayIterator
  * @see java.util.Iterator
  * @see java.util.ListIterator
  *

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/CollatingIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/CollatingIterator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/CollatingIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/CollatingIterator.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
 import java.util.ArrayList;
 import java.util.BitSet;
@@ -24,7 +24,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.NoSuchElementException;
 
-import org.apache.commons.collections.list.UnmodifiableList;
+import org.apache.commons.collections4.list.UnmodifiableList;
 
 
 /**
@@ -216,7 +216,7 @@ public class CollatingIterator<E> implem
      * would like to use the natural sort order (or, in other words,
      * if the elements in the iterators are implementing the
      * {@link java.lang.Comparable} interface), then use the
-     * {@link org.apache.commons.collections.comparators.ComparableComparator}.
+     * {@link org.apache.commons.collections4.comparators.ComparableComparator}.
      * 
      * @param comp the {@link Comparator} to set
      * @throws IllegalStateException if iteration has started

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyIterator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyIterator.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
 import java.util.Iterator;
 
-import org.apache.commons.collections.ResettableIterator;
+import org.apache.commons.collections4.ResettableIterator;
 
 /** 
  * Provides an implementation of an empty iterator.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyListIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyListIterator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyListIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyListIterator.java Wed Apr 17 17:37:03 2013
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
 import java.util.ListIterator;
 
-import org.apache.commons.collections.ResettableListIterator;
+import org.apache.commons.collections4.ResettableListIterator;
 
 /**
  * Provides an implementation of an empty list iterator.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyMapIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyMapIterator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyMapIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyMapIterator.java Wed Apr 17 17:37:03 2013
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
-import org.apache.commons.collections.MapIterator;
-import org.apache.commons.collections.ResettableIterator;
+import org.apache.commons.collections4.MapIterator;
+import org.apache.commons.collections4.ResettableIterator;
 
 /** 
  * Provides an implementation of an empty map iterator.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyOrderedIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyOrderedIterator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyOrderedIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyOrderedIterator.java Wed Apr 17 17:37:03 2013
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
-import org.apache.commons.collections.OrderedIterator;
-import org.apache.commons.collections.ResettableIterator;
+import org.apache.commons.collections4.OrderedIterator;
+import org.apache.commons.collections4.ResettableIterator;
 
 /** 
  * Provides an implementation of an empty ordered iterator.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyOrderedMapIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyOrderedMapIterator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyOrderedMapIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EmptyOrderedMapIterator.java Wed Apr 17 17:37:03 2013
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
-import org.apache.commons.collections.OrderedMapIterator;
-import org.apache.commons.collections.ResettableIterator;
+import org.apache.commons.collections4.OrderedMapIterator;
+import org.apache.commons.collections4.ResettableIterator;
 
 /** 
  * Provides an implementation of an empty ordered map iterator.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EntrySetMapIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EntrySetMapIterator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EntrySetMapIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EntrySetMapIterator.java Wed Apr 17 17:37:03 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
 import java.util.Iterator;
 import java.util.Map;
 
-import org.apache.commons.collections.MapIterator;
-import org.apache.commons.collections.ResettableIterator;
+import org.apache.commons.collections4.MapIterator;
+import org.apache.commons.collections4.ResettableIterator;
 
 /**
  * Implements a <code>MapIterator</code> using a Map entrySet.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EnumerationIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EnumerationIterator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EnumerationIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/EnumerationIterator.java Wed Apr 17 17:37:03 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
 import java.util.Collection;
 import java.util.Enumeration;

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/FilterIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/FilterIterator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/FilterIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/FilterIterator.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
 import java.util.Iterator;
 import java.util.NoSuchElementException;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /** 
  * Decorates another {@link Iterator} using a predicate to filter elements.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/FilterListIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/FilterListIterator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/FilterListIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/FilterListIterator.java Wed Apr 17 17:37:03 2013
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.collections.iterators;
+package org.apache.commons.collections4.iterators;
 
 import java.util.ListIterator;
 import java.util.NoSuchElementException;
 
-import org.apache.commons.collections.Predicate;
+import org.apache.commons.collections4.Predicate;
 
 /** 
  * Decorates another {@link ListIterator} using a predicate to filter elements.
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/Equator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/Equator.java Wed Apr 17 17:37:03 2013
@@ -8,7 +8,7 @@
  * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License
  * for the specific language governing permissions and limitations under the License.
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
 
 /**
  * <p>
@@ -37,7 +37,7 @@ public interface Equator<T> {
      * Calculates the hash for the object, based on the method of equality used in the equate
      * method. This is used for classes that delegate their {@link Object#equals(Object) equals(Object)} method to an
      * Equator (and so must also delegate their {@link Object#hashCode() hashCode()} method), or for implementations
      * of {@link org.apache.commons.collections.map.HashedMap} that use an Equator for the key objects.
      * 
      * @param o the object to calculate the hash for.
      * @return the hash of the object.
@@ -37,7 +37,7 @@ public interface Equator<T> {
      * method. This is used for classes that delegate their {@link Object#equals(Object) equals(Object)} method to an
      * Equator (and so must also delegate their {@link Object#hashCode() hashCode()} method), or for implementations
-     * of {@link org.apache.commons.collections.map.HashedMap} that use an Equator for the key objects.
+     * of {@link org.apache.commons.collections4.map.HashedMap} that use an Equator for the key objects.
      * 
      * @param o the object to calculate the hash for.

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ExceptionClosure.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/ExceptionClosure.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/package-info.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/package-info.java Wed Apr 17 17:37:03 2013
@@ -16,12 +16,12 @@
  */
 /**
  * This package contains implementations of the
  * {@link org.apache.commons.collections.Closure Closure},
  * {@link org.apache.commons.collections.Predicate Predicate},
  * {@link org.apache.commons.collections.Transformer Transformer} and
  * {@link org.apache.commons.collections.Factory Factory} interfaces.
  * These provide simple callbacks for processing with collections.
  * 
  * @version $Id$
  */
-package org.apache.commons.collections.functors;
+package org.apache.commons.collections4.functors;
@@ -16,12 +16,12 @@
 /**
  * This package contains implementations of the
- * {@link org.apache.commons.collections.Closure Closure},
- * {@link org.apache.commons.collections.Predicate Predicate},
- * {@link org.apache.commons.collections.Transformer Transformer} and
- * {@link org.apache.commons.collections.Factory Factory} interfaces.
+ * {@link org.apache.commons.collections4.Closure Closure},
+ * {@link org.apache.commons.collections4.Predicate Predicate},
+ * {@link org.apache.commons.collections4.Transformer Transformer} and
+ * {@link org.apache.commons.collections4.Factory Factory} interfaces.
  * These provide simple callbacks for processing with collections.
  * 

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractEmptyIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractEmptyIterator.java?rev=1469004&r1=1468597&r2=1469004&view=diff
==============================================================================